@@ -5,6 +5,7 @@ __all__ = [
     'line','loaddill','logger','extn', 'makedir', 'np', 'now','nunique','os','pad','pd','pdfilter','parent','Path','pdb',
     'plt','PIL','puttext','randint','rand','read','readlines','readPIL','rect','rename_batch','resize','see',
     'set_logging_level','show','stem','stems','subplots','sys','tqdm','Tqdm','Timer','unique','uint','writelines','zip_files','unzip_file',
+    'remove_duplicates', 'md5',
     'Info','Warn','Debug','Excep'
 ]
 
@@ -337,6 +338,7 @@ def subplots(ims, nc=5, figsize=(5,5), **kwargs):
     nr = (len(ims)//nc) if len(ims)%nc==0 else (1+len(ims)//nc)
     logger.info(f'plotting {len(ims)} images in a grid of {nr}x{nc} @ {figsize}')
     figsize = kwargs.pop('sz', figsize)
+    figsize = (figsize,figsize) if isinstance(figsize, int) else figsize
     fig, axes = plt.subplots(nr,nc,figsize=figsize)
     axes = axes.flat
     fig.suptitle(kwargs.pop('suptitle',''))
@@ -469,7 +471,7 @@ def writelines(lines, file):
 
 def zip_files(list_of_files, dest):
     import zipfile
-    Info(f'Zipping {len(list_of_files)} to {dest}...')
+    Info(f'Zipping {len(list_of_files)} files to {dest}...')
     with zipfile.ZipFile(dest, 'w') as zipMe:
         for file in Tqdm(list_of_files):
             zipMe.write(file, compress_type=zipfile.ZIP_DEFLATED)
@@ -479,9 +481,20 @@ def unzip_file(file, dest):
     with zipfile.ZipFile(file, 'r') as zip_ref:
         zip_ref.extractall(dest)
 
-'''108 ways to orgasm
-* Walk on soil
-* Drink clean water, eyes closed and sitting
-* When a sneeze comes, breath in instead of out
-* Feel your heart at the moment of sleep
-'''
+def md5(fname):
+    hash_md5 = hashlib.md5()
+    with open(fname, "rb") as f:
+        for chunk in iter(lambda: f.read(4096), b""):
+            hash_md5.update(chunk)
+    return hash_md5.hexdigest()
+
+def remove_duplicates(files):
+    hashes = [md5(f) for f in files]
+    df = pd.DataFrame({'f':files, 'h': hashes})
+    x = df.drop_duplicates('h')
+    y = diff(files, x.f)
+    for i in y:
+        os.rename(i, './x')
+    # !rm ./x
+    return
+
